BoundedUsize

Struct BoundedUsize 

pub struct BoundedUsize<const MIN: usize, const MAX: usize>(/* private fields */);
A BoundedUsize` that’s bounded between two values (inclusive)

Implementations

Source

impl<const MIN: usize, const MAX: usize> BoundedUsize<MIN, MAX>

pub fn new(num: usize) -> Result<Self, OutOfBoundsError<usize>>

Creates a new BoundedUsize from num.

Parameters
  • num - The value to be validated and wrapped as a new bounded number.
Returns
  • Ok(Self) if num is within MIN and MAX.
  • Err(OutOfBoundsError) if num is outside MIN and MAX.
pub unsafe fn new_unchecked(num: usize) -> Self

Create a new clamped BoundedUsize (unchecked). Assumes num is already clamped between MIN and MAX (inclusive).

Parameters
  • num - The value to be wrapped as a new bounded number. This must already be validated.
Returns
  • Self - A new instance of the bounded number wrapping the provided value.
Safety

This function is marked unsafe because it assumes that num is already checked to be within the range from MIN to MAX (inclusive). The caller must ensure that this assumption is upheld.

pub fn into_inner(self) -> usize

Returns the value as a primitive type